images#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : 重定向
# @Time         : 2024/12/3 15:41
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

"gpt-3.5-turbo,gpt-3.5-turbo-0125,gpt-3.5-turbo-0301,gpt-3.5-turbo-0613,gpt-3.5-turbo-1106,gpt-3.5-turbo-16k,gpt-3.5-turbo-16k-0613,gpt-3.5-turbo-instruct"

"""
gpt-4o-2024-08-06,chatgpt-4o-latest,
gpt-4o,gpt-4o-2024-05-13,
gpt-4,gpt-4-0125-preview,gpt-4-0314,gpt-4-0613,gpt-4-1106-preview,gpt-4-32k,gpt-4-32k-0314,gpt-4-32k-0613,gpt-4-turbo,gpt-4-turbo-2024-04-09,gpt-4-turbo-preview
"""

x = """
             
视频生成模型操作指南

- 视频生成能力对prompt提示词撰写的精细度与准确度要求较高，建议大家可以反复细化、调整、优化prompt，实现你的想法；
- AI大模型每次生成的内容具有不确定性，生成结果未达到100%可控生成，比如同时输入多个实体，可能不会都生成出来；颜色和数量可能未必匹配；同样的prompt提示词未必每次生成的回答或图片都一样，建议多次尝试；
- 示例与提示词仅供参考，建议大家撰写稿件、体验时自行探索。
- 此次为小范围体验，（1）超写实画质：模型生成的视频内容具备高清质感、真实感，可用于工业级商业场景例如广告宣传、创意视频生成等商业应用。（2）高语义一致：用户可以进行细致的刻画，例如生成主体的细节，人物概念的组合等。模型可以准确的表达出文本的内容。（3）运动画面流畅：可生成大幅度的合理运动，运动镜头流畅、符合物理规律，不易出现变形。（4）原生镜头转换：模型原生具备自动生成多视角同主体的镜头切换画面，增强画面叙事感。
- 示例与提示词仅供参考，建议大家撰写稿件、体验时自行探索。

注：为了给大家提供更好的服务体验，混元大模型仍在升级和调试中，使用过程中或可能有抖动，欢迎大家反馈问题，一起让它变得更好。
混元视频生成大模型体验入口
正式上线后，用户通过腾讯元宝APP-AI应用-AI视频即可使用该功能（前期需申请）
文生视频提示词撰写注意事项
输入一段文字，腾讯混元视频生成大模型可根据文本生成对应画面， 支持中文、英文输入，生成5秒视频，选择多种画幅。建议对你想要的画面进行尽可能详细的描述，并多次调整你的提示词，以达到最优画面，如果您是专业的影视艺术工作者，可以尝试用专业方式描述画面。如果你为非专业人士，建议可以参考以下格式撰写关键词：
用法1： 提示词 = 主体+场景+运动 
用法2： 提示词=主体（主体描述）+场景（场景描述）+运动（运动描述）+（镜头语言）+（氛围描述）+（风格表达）
用法3： 提示词 = 主体+场景+运动 + (风格表达)  + (氛围描述) + (运镜方式) + (光线) + (景别)

暂时无法在飞书文档外展示此内容

对画面进行更详细，精确的描述，会让生成的视频更加符合你的想法，并且进一步提升画面质感与细节。
提示词ver1：一个人坐在沙发上看书。
一个人坐在沙发上看书。-2.mp4

提示词ver2：一位戴着眼镜的老妇人坐在舒适的沙发上，全神贯注地阅读着一本书。一个冒着热气的茶杯放在咖啡桌上。房间里有书架，书架上放满书籍。
一位戴着眼镜的老妇人坐在舒适的沙发上，全神贯注地阅读着一本书。一个冒着热气的茶杯放在咖啡桌上。房间里有书架，书架上放满书籍。.mp4

提示词ver3：镜头慢慢推近。背景是一个小巧而温馨的客厅。一位年轻女子坐在舒适的沙发上，全神贯注地阅读着一本书。一个冒着热气的茶杯放在咖啡桌上，周围散落着一些靠垫。房间里摆满了植物和书架，给人一种温暖和宁静的感觉。昏暗的中景，舒适的客厅。现实主义风格。
镜头慢慢推近。背景是一个小巧而温馨的客厅。一位年轻女子坐在舒适的沙发上，全神贯注地阅读着一本书。一个冒着热气的茶杯放在咖啡桌上，周围散落着一些靠垫。房间里摆满了.mp4

优势能力&部分案例展示
以下为提示词以及生成的视频
（本文中相关视频均可各位媒体老师作为素材下载，可直接点开相应视频后点击右下角下载）
超写实质感
200mm长焦镜头，对准一只停在栏杆上的海鸥。羽毛的纹理清晰可辨，前景的木栏杆温柔虚化。远处的落日和海平面融化成金红色的光影
200mm长焦镜头，对准一只停在栏杆上的海鸥。羽毛的纹理清晰可辨，前景的木栏杆温柔虚化。远处的落日和海平面融化成金红色的光影.mp4

一个隐藏的瀑布流入清澈的池塘，周围是高大的树木和绿色植物。阳光穿过树叶，在下面的岩石和水面上形成斑点。逼真，茂密森林中的宁静瀑布，宁静、阳光明媚的日子，中景
一个隐藏的瀑布流入清澈的池塘，周围是高大的树木和绿色植物。阳光穿过树叶，在下面的岩石和水面上形成斑点。逼真，茂密森林中的宁静瀑布，宁静、阳光明媚的日子，中景.mp4

超广角仰拍，银河横跨夜空如璀璨星河。远处山脉轮廓若隐若现，篝火在前景点亮帐篷。人类与宇宙的静谧对话。
超广角仰拍.mov

暴风雪中，一列蒸汽火车在崎岖山间穿行，黑烟从车头直冲云霄，车厢在皑皑白雪中留下深邃轨迹，镜头以侧面追踪，捕捉机械巨兽破开风雪的磅礴气势，白雾与蒸汽交织成壮丽画卷，电影氛围，远景
暴风雪中，一列蒸汽火车在崎岖山间穿行，黑烟从车头直冲云霄，车厢在皑皑白雪中留下深邃轨迹，镜头以侧面追踪，捕捉机械巨兽破开风雪的磅礴气势，白雾与蒸汽交织成壮丽画卷，电影氛围，远景.mp4

低角度推进镜头，全景深。清晨，薄雾缭绕山间，红袍僧侣缓步前行，身影与远山轮廓相映。背景古木参天，阳光穿透云层洒落，形成光束。整体色调宁静，突出自然与人文的和谐共生。
低角度推进镜头，全景深.mov

水下广角，阳光从破损甲板射入形成光束阵列。鱼群穿过船舱窗户，铁锈和珊瑚共同装点残骸。历史与海洋生命交织的沉默诗篇。
水下广角，阳光从破损甲板射入形成光束阵列.mov

超长焦横移，工业废弃厂房，主光从碎裂天窗渗入，灰尘颗粒漂浮，人物剪影走过生锈机器，深褐色调
超长焦横移，工业废弃厂房，主光从碎裂天窗渗入.mov

对称构图蜂巢正中特写，单一顶光打出完美几何光影，蜜蜂群以严格对称队形飞出，每只蜂翼的频率形成视觉韵律，空间中的光线被切割成规则图案。
对称构图蜂巢正中特写，单一顶光打出完美几何光影.mov

高语义一致
一位戴着复古飞行护目镜的机械师，半跪在蒸汽朋克风格的工作室里。她棕色卷发挽成发髻，零星的银色发丝闪着金属光泽。深棕色皮质工装背带裤上沾满机油污渍，袖口卷起露出布满齿轮纹身的手臂。特写她正用黄铜工具调试一只机械鸟，齿轮间冒出缕缕蒸汽，工作台上散落着铜管、发条和老式图纸。
一位戴着复古飞行护目镜的机械师，半跪在蒸汽朋克风格的工作室里。她棕色卷发挽成发髻，零星的银色发丝闪着金属光泽。深棕色皮质工装背带裤上沾满机油污渍，袖口卷起露出布满齿轮纹身的手臂。特写她正用黄铜工具调试一只机械鸟，齿轮间冒出缕缕蒸汽，工作台上散落着铜管、发条和老式图纸。.mp4

固定机位的老公寓内景，自然光透过纱帘漫射，青色街灯渗入，茶烟袅袅升起，老式家具静静陈列，定格岁月流逝的时光。
语义一致.mov

45度俯视固定镜头，中景浅景深，晨光穿过梧桐斑驳洒落。画面中央的橘猫围着围裙，稳稳举刀切黄瓜，尾巴随着切菜节奏轻晃。背景灶台炊烟缭绕上升，阳光斜射在木案与老铁锅上泛起温暖光晕。
45度俯视固定镜头，中景浅景深，晨光穿过梧桐斑驳洒落。画面中央的橘猫围着围裙，稳稳举刀切黄瓜，尾巴随着切菜节奏轻晃。背景灶台炊烟缭绕上升，阳光斜射在木案与老铁锅上泛起温暖光晕。.mp4

90度俯瞰镜头，浅景深聚焦。画面中央的芭蕾舞者着白色轻纱，足尖点地旋转。裙摆如同绽放的睡莲，在水晶地面上映出万花筒般的倒影。特写她指尖划过空气，带起细微的波纹，每个动作都在光影间若隐若现。背景的丝绒幕布随气流轻轻波动，勾勒出完美的圆形构图。
芭蕾舞者.mp4

5度斜角固定镜头，浅景深对焦，紫红霓虹灯与青色全息投影交织。画面中央的机械舞者着装前卫，钛合金骨架上覆盖着半透明纳米纤维，每个关节都镶嵌着脉动的LED光环。她缓缓展开双臂，背部的石墨烯光翼像液态金属般流淌展开，翼尖闪烁着等离子般的蓝色电弧。
5度斜角固定镜头，浅景深对焦，紫红霓虹灯与青色全息投影交织。画面中央的机械舞者着装前卫，钛合金骨架上覆盖着半透明纳米纤维，每个关节都镶嵌着脉动的LED光环。她缓缓展开双臂，背部的石墨烯光翼像液态金属般流淌展开，翼尖闪烁着等离子般的蓝色电弧。.mp4

运动画面流畅

超大海浪，冲浪者在浪花上起跳，完成空中转体。摄影机从海浪内部穿越而出，捕捉阳光透过海水的瞬间。水花在空中形成完美弧线，冲浪板划过水面留下轨迹。最后定格在冲浪者穿越水帘的完美瞬间。
冲浪.mp4

穿着白床单的幽灵面对着镜子。镜子中可以看到幽灵的倒影。幽灵位于布满灰尘的阁楼中，阁楼里有老旧的横梁和被布料遮盖的家具。阁楼的场景映照在镜子中。幽灵在镜子前跳舞。电影氛围，电影打光
跳舞的幽灵.mp4

雨滴敲打着窗户。整个视频呈现出悲伤的氛围。
雨滴.mp4

草莓掉进鸡尾酒杯，溅起水花，高速摄影，2K
鸡尾酒.mp4

日落时分的越野赛道，改装过的福特F-150猛禽呼啸而过。加高的悬挂让硕大的防爆轮胎在泥地上肆意翻飞，泥浆飞溅在防滚架上形成斑驳图案。车身贴花在金色阳光下闪闪发亮，机械增压器的呼啸声与排气轰鸣交织。特写车轮陷入松软泥地又瞬间爆发，带起一串泥浆礼花。
日落时分的越野赛道，改装过的福特F-150猛禽呼啸而过。加高的悬挂让硕大的防爆轮胎在泥地上肆意翻飞，泥浆飞溅在防滚架上形成斑驳图案。车身贴花在金色阳光下闪闪发亮，机械增压器的呼啸声与排气轰鸣交织。特写车轮陷入松软泥地又瞬间爆发，带起一串泥浆礼花。.mp4

平移跟摄视角缓缓推进，景深中焦，暖色夕阳光线笼罩画面。画面中的女孩裙摆飘动奔跑，转身跃起，身影与橙红晚霞交织。背景海浪持续轻拍沙滩，洒落金色水花。
平移跟摄视角缓缓推进，景深中焦，暖色夕阳光线笼罩画面。画面中的女孩裙摆飘动奔跑，转身跃起，身影与橙红晚霞交织。背景海浪持续轻拍沙滩，洒落金色水花。.mp4

长焦镜头穿透漫天黄沙，捕捉远处黎明沙丘的剪影。画面中央，一只体态圆润的大熊猫正缓缓展开太极动作，黑白皮毛在旋转的沙尘中若隐若现。摄影机低角度环绕，熊猫毛发随风舞动，每个动作都与席卷的沙浪完美融合。逆光中，它的身影与起伏的沙丘勾勒出东方水墨意境。
长焦镜头穿透漫天黄沙，捕捉远处黎明沙丘的剪影。画面中央，一只体态圆润的大熊猫正缓缓展开太极动作，黑白皮毛在旋转的沙尘中若隐若现。摄影机低角度环绕，熊猫毛发随风舞动，每个动作都与席卷的沙浪完美融合。逆光中，它的身影与起伏的沙丘勾勒出东方水墨意境。.mp4

进阶用法&部分案例展示
进阶1： 多镜头生成
功能：模型生成前后镜头自然切换，但内容保持一致的视频
提示词 = [场景1] + 镜头切换到 [场景2] 
cases:
暂时无法在飞书文档外展示此内容

进阶2：两个动作生成
功能：模型生成包含两个连贯动作的视频
提示词 = [主体描述]+[动作描述] + [然后、过了一会等连接词] + [动作描述2]
cases：
暂时无法在飞书文档外展示此内容

""".replace("腾讯混元", "").replace("腾讯", "").replace("混元", "")